import React, { useEffect, useState } from 'react';
import { SafeAreaView, View, Text, Image, StatusBar, StyleSheet, Platform } from 'react-native';
import { Button } from 'react-native-elements';

import c_styles from '../../styles';
import pxToDp from '../../core/pxToDp';
import AuthInput from './components/input';
import { auth } from '../../api';

const styles = StyleSheet.create({
    ...c_styles,
    logo_view: { height: pxToDp(480) },
    logo_view_bg: { width: '100%', height: '100%' },
    content: { position: 'absolute', top: 0, left: 0, width: '100%', height: '100%' },
    title: { color: '#fff', fontSize: pxToDp(40), fontWeight: '500', marginTop: pxToDp(136) },
    logo: { width: pxToDp(180), height: pxToDp(180), marginTop: pxToDp(40) },
    input_view: { backgroundColor: '#fff', borderTopRightRadius: pxToDp(30), borderTopLeftRadius: pxToDp(30), marginTop: pxToDp(53), flex: 1, width: '100%' },
    forget_view: { width: pxToDp(551), marginBottom: pxToDp(80) }
})

const Forget = (props) => {
    const { navigation } = props;
    const [mobile, setMobile] = useState('');
    const [code, setCode] = useState('');
    const [password, setPassword] = useState('');
    const [password_confirmation, setPasswordConfirmation] = useState('');

    useEffect(() => {
        if (Platform.OS === 'android') {
            StatusBar.setBackgroundColor('#fff');
        }
        StatusBar.setBarStyle('dark-content');

        return () => {
            if (Platform.OS === 'android') {
                StatusBar.setBackgroundColor('#0D9DEF', true);
            }
            StatusBar.setBarStyle('light-content');
        }
    }, []);

    // 获取验证码
    const getCodeSMS = async (cb) => {
        if (mobile.length !== 11) {
            GLOBAL.Toast.show('请输入正确的手机号', 'info', 1);
            return
        }

        let key = GLOBAL.Toast.show('获取中');
        try {
            let result = await auth.getCode(mobile, 3);
            console.log(result);
            GLOBAL.Toast.hide(key);
            GLOBAL.Toast.show('验证码发送成功', 'success', 1);
            cb();
        } catch (e) {
            GLOBAL.Toast.hide(key);
            GLOBAL.Toast.show(e.message, 'fail', 1);
        }
    }

    // 提交
    const submit = async () => {
        if (mobile.length !== 11) {
            GLOBAL.Toast.show('请输入正确的手机号', 'info', 1);
            return
        }
        if (!code) {
            GLOBAL.Toast.show('请输入验证码', 'info', 1);
            return
        }
        if (!password) {
            GLOBAL.Toast.show('请输入您的新密码', 'info', 1);
            return
        }
        if (!password_confirmation) {
            GLOBAL.Toast.show('请再次输入您的新密码', 'info', 1);
            return
        }
        if (password !== password_confirmation) {
            GLOBAL.Toast.show('两次输入的密码不一致', 'info', 1);
            return
        }

        let key = GLOBAL.Toast.show('提交中');
        try {
            let result = await auth.retrievePsd(mobile, code, password, password_confirmation);
            console.log(result);
            GLOBAL.Toast.hide(key);
            GLOBAL.Toast.show('提交成功', 'success', 1, () => {
                navigation.goBack();
            });
        } catch (e) {
            GLOBAL.Toast.hide(key);
            GLOBAL.Toast.show(e.message || '提交失败', 'fail', 1);
        }
    }

    return (
        <SafeAreaView style={[styles.safeAreaView, styles.flex, styles.align_center]}>
            <AuthInput
                leftIcon={require('../../../assets/images/phone.png')}
                styles={{ marginTop: pxToDp(50), marginBottom: pxToDp(50) }}
                placeholder="请输入您已经绑定的手机号"
                keyboardType="phone-pad"
                maxLength={11}
                onChangeText={(text) => { setMobile(text); }}
            />
            <AuthInput
                leftIcon={require('../../../assets/images/verify.png')}
                styles={{ marginBottom: pxToDp(50) }}
                isVerify={true}
                placeholder="请输入验证码"
                keyboardType="number-pad"
                maxLength={6}
                onChangeText={(text) => { setCode(text); }}
                getCode={getCodeSMS}
            />
            <AuthInput
                leftIcon={require('../../../assets/images/password.png')}
                styles={{ marginBottom: pxToDp(50) }}
                isPassword={true}
                placeholder="请输入您的新密码"
                onChangeText={(text) => { setPassword(text); }}
            />
            <AuthInput
                leftIcon={require('../../../assets/images/password.png')}
                styles={{ marginBottom: pxToDp(90) }}
                isPassword={true}
                placeholder="请再次输入您的新密码"
                onChangeText={(text) => { setPasswordConfirmation(text); }}
            />
            <Button
                title='确定并返回登录'
                containerStyle={{ width: pxToDp(550) }}
                buttonStyle={{ backgroundColor: '#0D9DEF', height: pxToDp(78), borderRadius: pxToDp(39) }}
                titleStyle={{ fontSize: pxToDp(30) }}
                onPress={submit}
            />
        </SafeAreaView>
    )
}

export default Forget;