import React, { useEffect, useState } from 'react';
import { useDispatch } from 'react-redux';
import { SafeAreaView, View, Text, Image, StatusBar, StyleSheet } from 'react-native';
import { Button } from 'react-native-elements';

import c_styles from '../../styles';
import pxToDp from '../../core/pxToDp';
import { Touchable, Adapter } from '../../components';
import AuthInput from './components/input';
import { auth, user } from '../../api';
import { saveToken, updateUserInfo } from '../../reducers';

const styles = StyleSheet.create({
    ...c_styles,
    logo_view: { height: pxToDp(480) },
    logo_view_bg: { width: '100%', height: '100%' },
    content: { position: 'absolute', top: 0, left: 0, width: '100%', height: '100%' },
    title: { color: '#fff', fontSize: pxToDp(40), fontWeight: '500', marginTop: pxToDp(136) },
    logo: { width: pxToDp(180), height: pxToDp(180), marginTop: pxToDp(40) },
    input_view: { backgroundColor: '#fff', borderTopRightRadius: pxToDp(30), borderTopLeftRadius: pxToDp(30), marginTop: pxToDp(53), flex: 1, width: '100%' },
    forget_view: { width: pxToDp(551), marginBottom: pxToDp(80) }
})

const Login = (props) => {
    const { navigation } = props;
    const dispatch = useDispatch();
    const [username, setUsername] = useState('');
    const [password, setPassword] = useState('');

    useEffect(() => {
        StatusBar.setBarStyle('light-content');
    }, []);

    // 跳转页面
    const navigationTo = (path, params) => {
        navigation.navigate(path, params);
    }

    // 登录
    const login = async () => {
        if (!username) {
            GLOBAL.Toast.show('请输入您的账号或手机号', 'info', 1);
            return
        }
        if (!password) {
            GLOBAL.Toast.show('请输入密码', 'info', 1);
            return
        }

        let key = GLOBAL.Toast.show('登录中');
        try {
            let result = await auth.login(username, password);
            dispatch(saveToken(result.token));
            let userInfo = await user.getUserInfo();
            dispatch(updateUserInfo(userInfo));
            GLOBAL.Toast.hide(key);
            GLOBAL.Toast.show('登录成功', 'success', 1, () => {
                navigation.reset({
                    index: 0,
                    routes: [{ name: 'Tab' }],
                });
            });
        } catch (e) {
            GLOBAL.Toast.hide(key);
            GLOBAL.Toast.show(e.message || '登录失败', 'fail', 1);
        }
    }

    return (
        <View style={[styles.safeAreaView]}>
            <View style={styles.logo_view}>
                <Image style={styles.logo_view_bg} source={require('../../../assets/images/beijing.png')} />
            </View>
            <View style={[styles.content, styles.flex, styles.flex_direction_column, styles.align_center]}>
                <Text style={styles.title}>平望镇智锁云旅店</Text>
                <Image style={styles.logo} source={require('../../../assets/images/logo.png')} />
                <View style={[styles.input_view, styles.flex, styles.flex_direction_column, styles.align_center]}>
                    <Text style={{ color: '#28282C', fontSize: pxToDp(36), fontWeight: '500', marginTop: pxToDp(61) }}>用户登录</Text>
                    <AuthInput
                        leftIcon={require('../../../assets/images/account.png')}
                        styles={{ marginTop: pxToDp(66), marginBottom: pxToDp(50) }}
                        placeholder="请输入您的账号/手机号"
                        onChangeText={(text) => { setUsername(text); }}
                    />
                    <AuthInput
                        leftIcon={require('../../../assets/images/password.png')}
                        isPassword={true}
                        placeholder="请输入您的密码"
                        onChangeText={(text) => { setPassword(text); }}
                    />
                    <View style={[styles.forget_view, styles.flex, styles.align_end]}>
                        <Button
                            title='忘记密码?'
                            type="clear"
                            buttonStyle={{ padding: pxToDp(20), paddingRight: 0 }}
                            titleStyle={{ fontSize: pxToDp(24), color: '#0D9DEF' }}
                            onPress={() => { navigationTo('Forget'); }}
                        />
                    </View>
                    <Button
                        title='登录'
                        containerStyle={{ width: pxToDp(550) }}
                        buttonStyle={{ backgroundColor: '#0D9DEF', height: pxToDp(78), borderRadius: pxToDp(39) }}
                        titleStyle={{ fontSize: pxToDp(30) }}
                        onPress={login}
                    />
                    {/* <View style={[styles.flex, styles.flex_direction_row, styles.align_center, styles.justify_center, { marginTop: pxToDp(20) }]}>
                        <Text style={[styles.theme_text, { fontSize: pxToDp(24) }]}>还没账号，</Text>
                        <Touchable onPress={() => { navigationTo('Register'); }}>
                            <Text style={[styles.theme_color, { fontSize: pxToDp(24), textDecorationLine: 'underline' }]}>立即注册</Text>
                        </Touchable>
                    </View> */}
                </View>
            </View>
        </View>
    )
}

export default Login;