import React, { useEffect, useState, useRef } from 'react';
import { useSelector, useDispatch } from 'react-redux';
import { SafeAreaView, View, StatusBar, StyleSheet, Image, Text, Platform } from 'react-native';

import c_styles from '../../styles';
import pxToDp from '../../core/pxToDp';
import { RefreshState, RefreshListView } from '../../components';
import AlarmCell from './components/alarmcell';
import Date from './components/date';
import Dropdown from '../tenant/components/dropdown';
import { record } from '../../api';

const styles = StyleSheet.create({
  ...c_styles,
  date: { marginLeft: pxToDp(30), marginRight: pxToDp(30), marginTop: pxToDp(20) },
  drop: { height: pxToDp(80), marginLeft: pxToDp(30), marginRight: pxToDp(30) }
});

const Index = (props) => {
  const { navigation } = props;
  const [page, setPage] = useState(1);
  const [refreshState, setRefreshState] = useState(RefreshState.Idle);
  const [data, setData] = useState([]);
  const [start_date, setStartDate] = useState('');
  const [village_id, setVillageId] = useState('');
  const [group_id, setGroupId] = useState('');
  const [building_id, setBuildingId] = useState('');
  const [room_id, setRoomId] = useState('');
  const dateRef = useRef();

  useEffect(() => {
    if (Platform.OS === 'android') {
      StatusBar.setBackgroundColor('#fff');
    }
    StatusBar.setBarStyle('dark-content');
    onHeaderRefresh();

    return () => {
      if (Platform.OS === 'android') {
        StatusBar.setBackgroundColor('#0D9DEF', true);
      }
      StatusBar.setBarStyle('light-content');
    }
  }, []);

  useEffect(() => {
    if (start_date) {
      onHeaderRefresh();
    }
  }, [start_date]);

  useEffect(() => {
    if (village_id || group_id || building_id || room_id) {
      onHeaderRefresh();
    }
  }, [village_id, group_id, building_id, room_id]);

  // 下拉刷新
  const onHeaderRefresh = async () => {
    setPage(1);
    setData([]);

    setRefreshState(RefreshState.HeaderRefreshing);

    let result = await record.getWarningRecords({ page: 1, start_date, village_id, group_id, building_id, room_id });
    setPage(2);
    setData(result.data || []);
    setRefreshState(RefreshState.Idle);
  }

  // 上拉加载
  const onFooterRefresh = async () => {
    if (refreshState === RefreshState.NoMoreData) { return }

    setRefreshState(RefreshState.FooterRefreshing);

    let result = await record.getWarningRecords({ page, start_date, village_id, group_id, building_id, room_id });
    setPage(page + 1);
    setData(GLOBAL._.concat(data, result.data || []));
    if ((result.data || []).length === 0) {
      setRefreshState(RefreshState.NoMoreData);
    } else {
      setRefreshState(RefreshState.Idle);
    }
  }

  const onSearch = (value) => {
    setStartDate(value);
  }

  const renderCell = ({ item, index }) => {
    return (
      <AlarmCell key={index} info={item} showStatus />
    )
  }

  return (
    <SafeAreaView style={styles.container}>
      <View style={styles.date}>
        <Date leftText="报警时间" placeholder='请选择日期' onSearch={onSearch} ref={dateRef} />
      </View>
      <View style={styles.drop}>
        <Dropdown selectVillage={(value) => {
          setVillageId(value.id);
          setGroupId('');
          setBuildingId('');
          setRoomId('');
        }} selectGroup={(value) => {
          setGroupId(value.id);
          setBuildingId('');
          setRoomId('');
        }} selectBuilding={(value) => {
          setBuildingId(value.id);
          setRoomId('');
        }} selectRoom={(value) => {
          setRoomId(value.id);
        }}/>
      </View>
      <RefreshListView
        listRef={`RefreshView`}
        style={{ flex: 1 }}
        data={data}
        keyExtractor={(item, idx) => idx.toString()}
        renderItem={renderCell}
        refreshState={refreshState}
        onHeaderRefresh={onHeaderRefresh}
        onFooterRefresh={onFooterRefresh}

        // 可选
        footerRefreshingText='玩命加载中 >.<'
        footerFailureText='我擦嘞，居然失败了 — —！'
        footerNoMoreDataText='没有数据了 — —！'
      />
    </SafeAreaView>
  )
}

export default Index;