import React, { useState, useEffect, useRef, useImperativeHandle } from 'react';
import { StyleSheet, View, Text, Image } from 'react-native';
import { DatePicker, Flex } from '@ant-design/react-native';
import { Button } from 'react-native-elements';

import c_styles from '../../../styles';
import pxToDp from '../../../core/pxToDp';
import { Touchable } from '../../../components';

const styles = StyleSheet.create({
  ...c_styles,
  container_style: { backgroundColor: '#fff', padding: pxToDp(30), paddingTop: pxToDp(20), paddingBottom: pxToDp(20), borderRadius: pxToDp(10) },
  left_text: { fontSize: pxToDp(30), marginRight: pxToDp(14) },
  picker: { borderWidth: pxToDp(1), borderColor: '#e1e1e1', borderTopLeftRadius: pxToDp(10), borderBottomLeftRadius: pxToDp(10), padding: pxToDp(15) },
  right_icon: { width: pxToDp(30), height: pxToDp(30) }
});

const Index = (props, ref) => {
  const [selDate, setSelDate] = useState('');

  useImperativeHandle(ref, () => ({
    clearDate: () => {
      setSelDate('');
    }
  }))

  return (
    <View style={[styles.container_style, props.style || {}]}>
      <Flex>
        <Text style={[styles.left_text, styles.theme_text]}>{props.leftText}</Text>
        <Flex.Item style={styles.picker}>
          <DatePicker
            defaultDate={new Date()}
            mode='date'
            cols={1}
            title='选择类目'
            onChange={(value) => {
              setSelDate(GLOBAL.moment(value).format('YYYY-MM-DD'));
            }}
          >
            <Touchable style={[styles.flex]}>
              <Flex>
                <Flex.Item>
                  {
                    props.placeholder && !selDate && (
                      <Text style={{ fontSize: pxToDp(28), color: '#999' }}>{props.placeholder}</Text>
                    )
                  }
                  {
                    Boolean(selDate) && (
                      <Text style={[styles.theme_text, { fontSize: pxToDp(28) }]}>{selDate}</Text>
                    )
                  }
                </Flex.Item>
                <Image style={styles.right_icon} source={require('../../../../assets/images/riqi.png')} />
              </Flex>
            </Touchable>
          </DatePicker>
        </Flex.Item>
        <Button
          title='搜索'
          containerStyle={{ borderRadius: 0 }}
          buttonStyle={{ backgroundColor: '#0D9DEF', borderRadius: 0, borderTopRightRadius: pxToDp(10), borderBottomRightRadius: pxToDp(10), borderWidth: pxToDp(2), borderColor: '#0D9DEF' }}
          titleStyle={{ fontSize: pxToDp(24) }}
          onPress={() => {
            props.onSearch && props.onSearch(selDate);
          }}
        />
      </Flex>

    </View>
  )
}

export default React.forwardRef(Index)