import React, { useState, useRef, useEffect } from 'react';
import { StyleSheet, View, Image } from 'react-native';
import { Input, Button } from 'react-native-elements';

import c_styles from '../../../styles';
import pxToDp from '../../../core/pxToDp';
import { Touchable } from '../../../components';

const styles = StyleSheet.create({
  ...c_styles,
  left_icon: { width: pxToDp(30), height: pxToDp(30) },
  psd_icon: { width: pxToDp(30), height: pxToDp(30) },
  content: { width: pxToDp(503), height: pxToDp(70), borderBottomColor: '#E1E1E1', borderBottomWidth: pxToDp(1), marginLeft: pxToDp(18) }
});


const Index = (props) => {
  const psd_open = require('../../../../assets/images/psd_open.png');
  const psd_close = require('../../../../assets/images/psd_close.png');
  const [showPsd, setShowPsd] = useState(false);// 是否显示密码
  const [codeCount, setCodeCount] = useState(0);// 倒计时
  const timer = useRef(null);

  // 组件卸载时清除计时器
  useEffect(() => {
    return () => {
      clearInterval(timer.current);
    };
  }, []);

  useEffect(() => {
    if (codeCount === 59) {
      timer.current = setInterval(() => {
        setCodeCount((preCount) => preCount - 1);
      }, 1000);
    } else if (codeCount === 0) {
      clearInterval(timer.current);
    }
  }, [codeCount])

  // 切换密码显示状态
  const togglePsdStatus = () => {
    setShowPsd(!showPsd);
  }

  // 发送验证码
  const getCode = () => {
    props.getCode && props.getCode(() => {
      setCodeCount(59);
    });
  }

  return (
    <View style={[styles.flex, styles.flex_direction_row, styles.align_center, props.styles || {}]}>
      {
        props.leftIcon && (
          <Image style={styles.left_icon} source={props.leftIcon} />
        )
      }
      <View style={[styles.content, styles.flex, styles.flex_direction_row, styles.align_center]}>
        <Input
          keyboardType={props.keyboardType}
          containerStyle={{ flex: 1, marginRight: pxToDp(20), height: '100%', paddingHorizontal: 0 }}
          inputContainerStyle={{ width: '100%', height: '100%', borderBottomWidth: 0 }}
          inputStyle={{ fontSize: pxToDp(28) }}
          autoFocus={false}
          autoCapitalize="none"
          autoCorrect={false}
          selectionColor="#0D9DEF"
          placeholderTextColor="#999"
          placeholder={props.placeholder || ''}
          onChangeText={props.onChangeText || null}
          maxLength={props.maxLength}
          secureTextEntry={props.isPassword ? !showPsd : false}
        />
        {
          props.isPassword && (
            <Touchable onPress={togglePsdStatus}>
              <Image style={styles.psd_icon} source={!showPsd ? psd_open : psd_close} />
            </Touchable>
          )
        }
        {
          props.isVerify && (
            <Button
              title={codeCount ? `${codeCount}秒` : '获取验证码'}
              disabled={codeCount ? true : false}
              type="clear"
              buttonStyle={{ padding: pxToDp(20), paddingRight: 0 }}
              titleStyle={{ fontSize: pxToDp(24), color: '#0D9DEF' }}
              onPress={getCode}
            />
          )
        }
      </View>
    </View>
  )
}

export default Index