import React, { useEffect, useState } from 'react';
import { useSelector, useDispatch } from 'react-redux';
import { ScrollView, View, Text, StatusBar, StyleSheet, Image, Platform } from 'react-native';
import { Carousel, Flex, WhiteSpace } from '@ant-design/react-native';
import AntDesignIcon from 'react-native-vector-icons/AntDesign';

import c_styles from '../../styles';
import pxToDp from '../../core/pxToDp';
import { Touchable } from '../../components';
import HomeCell from './components/homecell';
import Modal from './components/modal';
import { auth, home } from '../../api';
import { clearUserInfo } from '../../reducers';

const styles = StyleSheet.create({
  ...c_styles,
  bg_view: { height: pxToDp(282) },
  bg_view_img: { width: '100%', height: '100%' },
  content: { position: 'absolute', top: 0, left: 0, width: '100%', height: '100%' },
  title: { color: '#fff', fontSize: pxToDp(34), fontWeight: '500', textAlign: 'center' },
  info_view: { width: '100%', flex: 1 },
  carousel: { margin: pxToDp(30), marginTop: 0, marginBottom: 0, height: pxToDp(320), borderRadius: pxToDp(10) },
  carousel_cell: { height: '100%', width: '100%', borderRadius: pxToDp(10) },
  induction: {},
  induction_cell: { borderRadius: pxToDp(10), backgroundColor: '#f5f5f5', padding: pxToDp(30) },
  induction_cell_title: { fontSize: pxToDp(28) },
  induction_cell_success: { backgroundColor: '#00C22E', width: pxToDp(10), height: pxToDp(10), borderRadius: pxToDp(10) },
  induction_cell_fail: { backgroundColor: '#FF3030', width: pxToDp(10), height: pxToDp(10), borderRadius: pxToDp(10) },
  induction_cell_status: { color: '#666', fontSize: pxToDp(24), marginLeft: pxToDp(8) },
  data_view: { marginLeft: pxToDp(30), marginRight: pxToDp(30), marginTop: pxToDp(20), marginBottom: pxToDp(20), backgroundColor: '#fff', borderRadius: pxToDp(10) },
  menus: { marginLeft: pxToDp(30), marginRight: pxToDp(30), marginBottom: pxToDp(50) },
  menu_cell: { backgroundColor: '#fff', borderRadius: pxToDp(10), paddingTop: pxToDp(34), paddingBottom: pxToDp(34) }
});

const Home = (props) => {
  const dispatch = useDispatch();
  const userInfo = useSelector((state) => state.user);
  const { navigation } = props;
  const menus = [
    { title: '租客信息', icon: require('../../../assets/images/zukexinxi.png'), path: 'Tenant' },
    { title: '审核租客信息', icon: require('../../../assets/images/shenhezukexinxi.png'), path: 'TenantExamine' },
    { title: '智能门锁', icon: require('../../../assets/images/zhinengmensuo.png'), path: 'IotList', params: { title: '智能门锁', type: 'lock' } },
    { title: '智慧烟感', icon: require('../../../assets/images/zhihuiyangan.png'), path: 'IotList', params: { title: '智慧烟感', type: 'smoke' } },
    { title: '修改密码', icon: require('../../../assets/images/xiugaimima.png'), path: 'ModifyPsd' },
    { title: '报警记录', icon: require('../../../assets/images/baojingjilu.png'), path: 'AlarmRecord' }
  ];
  const [banners, setBanners] = useState([
    { url: require('../../../assets/images/banner.png') }
  ]);
  const [isVisible, setIsVisible] = useState(false);
  const [homeInfo, setHomeInfo] = useState({});

  useEffect(() => {
    if (Platform.OS === 'android') {
      StatusBar.setBackgroundColor('#0D9DEF');
    }
    StatusBar.setBarStyle('light-content');
  }, []);

  useEffect(() => {
    if (!GLOBAL._.isEmpty(userInfo)) {
      getHomeInfo();
    }
  }, [userInfo]);

  const getHomeInfo = async () => {
    let result = await home.getHomeInfo();
    setHomeInfo(result);
  }

  // 跳转页面
  const navigationTo = (path, params = {}) => {
    path && navigation.navigate(path, params);
  }

  // 退出登录
  const logout = async () => {
    setIsVisible(false);
    let key = GLOBAL.Toast.show('登出中');
    try {
      let result = await auth.logout();
      console.log(result);
      dispatch(clearUserInfo());
      GLOBAL.Toast.hide(key);
      GLOBAL.Toast.show('登出成功', 'success', 1, () => {
        navigation.reset({
          index: 0,
          routes: [{ name: 'Login' }],
        });
      });
    } catch (e) {
      console.log(e)
      GLOBAL.Toast.hide(key);
      GLOBAL.Toast.show(e.message || '登出失败', 'fail', 1);
    }
  }

  return (
    <View style={[styles.container]}>
      <View style={styles.bg_view}>
        <Image style={styles.bg_view_img} source={require('../../../assets/images/shouyebeijing.png')} />
      </View>
      <View style={[styles.content, styles.flex]}>
        <Flex style={{ marginTop: pxToDp(Platform.OS === 'android' ? 40 : 117), marginBottom: pxToDp(30), paddingLeft: pxToDp(30), paddingRight: pxToDp(30) }}>
          <View style={{ width: pxToDp(35) }}></View>
          <Flex.Item justify='center'>
            <Text style={styles.title}>平望镇智锁云旅店</Text>
          </Flex.Item>
          <Touchable onPress={() => { setIsVisible(true); }}>
            <AntDesignIcon name="logout" size={pxToDp(35)} color="#fff" />
          </Touchable>
        </Flex>
        <ScrollView style={[styles.info_view, styles.flex_sub]}>
          <Carousel style={styles.carousel} autoplay infinite dots={false}>
            {
              banners.map((item, index) => {
                return (
                  <Touchable noHighlight style={[styles.carousel_cell]} key={index} onPress={() => {
                  }}>
                    <Image style={styles.carousel_cell} source={item.url} />
                  </Touchable>
                )
              })
            }
          </Carousel>
          <View style={styles.data_view}>
            <View style={{ padding: pxToDp(30) }}>
              <Flex justify='between'>
                <Flex>
                  <Image style={{ width: pxToDp(30), height: pxToDp(30), marginRight: pxToDp(10) }} source={require('../../../assets/images/zongshuju.png')} />
                  <Text style={[styles.theme_text, { fontSize: pxToDp(30), fontWeight: "500" }]}>本区总数据</Text>
                </Flex>
                <Text style={[styles.theme_text, { fontSize: pxToDp(24) }]}>租客总量：{homeInfo.tenant_count || 0}人</Text>
              </Flex>
              <WhiteSpace size='lg' />
              <Flex style={styles.induction}>
                <Flex.Item style={[styles.induction_cell, { marginRight: pxToDp(30) }]}>
                  <Flex direction='column'>
                    <Text style={[styles.induction_cell_title, styles.theme_text]}>智慧烟感</Text>
                    <WhiteSpace size='lg' />
                    <Flex>
                      <Flex.Item>
                        <Flex direction='column'>
                          <Text>{homeInfo.smoke_normal_count || 0}只</Text>
                          <WhiteSpace />
                          <Flex>
                            <View style={styles.induction_cell_success}></View>
                            <Text style={styles.induction_cell_status}>正常</Text>
                          </Flex>
                        </Flex>
                      </Flex.Item>
                      <Flex.Item>
                        <Flex direction='column'>
                          <Text>{homeInfo.smoke_abnormal_count || 0}只</Text>
                          <WhiteSpace />
                          <Flex>
                            <View style={styles.induction_cell_fail}></View>
                            <Text style={styles.induction_cell_status}>异常</Text>
                          </Flex>
                        </Flex>
                      </Flex.Item>
                    </Flex>
                  </Flex>
                </Flex.Item>
                <Flex.Item style={[styles.induction_cell]}>
                  <Flex direction='column'>
                    <Text style={[styles.induction_cell_title, styles.theme_text]}>智能门锁</Text>
                    <WhiteSpace size='lg' />
                    <Flex>
                      <Flex.Item>
                        <Flex direction='column'>
                          <Text>{homeInfo.lock_normal_count || 0}把</Text>
                          <WhiteSpace />
                          <Flex>
                            <View style={styles.induction_cell_success}></View>
                            <Text style={styles.induction_cell_status}>正常</Text>
                          </Flex>
                        </Flex>
                      </Flex.Item>
                      <Flex.Item>
                        <Flex direction='column'>
                          <Text>{homeInfo.lock_abnormal_count || 0}把</Text>
                          <WhiteSpace />
                          <Flex>
                            <View style={styles.induction_cell_fail}></View>
                            <Text style={styles.induction_cell_status}>异常</Text>
                          </Flex>
                        </Flex>
                      </Flex.Item>
                    </Flex>
                  </Flex>
                </Flex.Item>
              </Flex>
            </View>
            <View style={{ height: pxToDp(1), width: '100%', backgroundColor: '#e1e1e1' }}></View>
            <HomeCell title='本日总数据' warnings_count={homeInfo.warnings_today_count} abnormal_count={homeInfo.lock_abnormal_today_count} clickCell={() => {
              let start_date = GLOBAL.moment().format('YYYY-MM-DD');
              let end_date = GLOBAL.moment().add(1, 'days').format('YYYY-MM-DD');
              navigationTo('TotalData', { title: '本日总数据', start_date, end_date });
            }} />
            <HomeCell title='本周总数据' warnings_count={homeInfo.warnings_week_count} abnormal_count={homeInfo.lock_abnormal_week_count} clickCell={() => {
              let start_date = GLOBAL.moment().weekday(0).format('YYYY-MM-DD');
              let end_date = GLOBAL.moment().weekday(7).format('YYYY-MM-DD');
              navigationTo('TotalData', { title: '本周总数据', start_date, end_date });
            }} />
            <HomeCell title='本月总数据' warnings_count={homeInfo.warnings_month_count} abnormal_count={homeInfo.lock_abnormal_month_count} style={{ borderBottomWidth: 0 }} clickCell={() => {
              let start_date = GLOBAL.moment().startOf('month').format('YYYY-MM-DD');
              let end_date = GLOBAL.moment().endOf('month').format('YYYY-MM-DD');
              navigationTo('TotalData', { title: '本月总数据', start_date, end_date });
            }} />
          </View>
          <View style={styles.menus}>
            <Flex wrap='wrap'>
              {
                menus.map((item, index) => {
                  return (
                    <View key={index} style={{ width: '33.3%' }}>
                      <Touchable onPress={() => { navigationTo(item.path, item.params); }}>
                        <Flex direction='column' key={index} style={[styles.menu_cell, { marginRight: index % 3 === 2 ? 0 : pxToDp(20), marginBottom: pxToDp(20) }]}>
                          <Image style={{ width: pxToDp(44), height: pxToDp(44) }} source={item.icon} />
                          <Text style={[styles.theme_text, { fontSize: pxToDp(24), marginTop: pxToDp(15) }]}>{item.title || ''}</Text>
                        </Flex>
                      </Touchable>
                    </View>
                  )
                })
              }
            </Flex>
          </View>
        </ScrollView>
      </View>

      <Modal isVisible={isVisible} title="退出登录" content="是否确定退出登录？" onCancel={() => {
        setIsVisible(false);
      }} onSure={logout} />
    </View>
  )
}

export default Home;