import React, { useEffect, useState } from 'react';
import { useSelector, useDispatch } from 'react-redux';
import { SafeAreaView, View, StatusBar, StyleSheet, Dimensions, Platform, } from 'react-native';
import { Tabs } from '@ant-design/react-native';

import c_styles from '../../styles';
import pxToDp from '../../core/pxToDp';
import { RefreshState, RefreshListView, Tabbar } from '../../components';
import IotCell from './components/iotcell';
import Dropdown from '../tenant/components/dropdown';
import { iot } from '../../api';

const styles = StyleSheet.create({
  ...c_styles,
  drop: { height: pxToDp(80), marginLeft: pxToDp(30), marginRight: pxToDp(30) },
});

const Index = (props) => {
  const { navigation, route } = props;
  const params = route.params || {};
  const [page, setPage] = useState(1);
  const [refreshState, setRefreshState] = useState(RefreshState.Idle);
  const [data, setData] = useState([1, 2]);
  const [status, setStatus] = useState(1);
  const [village_id, setVillageId] = useState('');
  const [group_id, setGroupId] = useState('');
  const [building_id, setBuildingId] = useState('');
  const [room_id, setRoomId] = useState('');
  const tabs = [
    { title: '正常' },
    { title: '异常' }
  ];
  const screen_width = Dimensions.get('window').width;

  useEffect(() => {
    if (Platform.OS === 'android') {
      StatusBar.setBackgroundColor('#fff');
    }
    StatusBar.setBarStyle('dark-content');
    navigation.setOptions({ title: params.title || '' });

    return () => {
      if (Platform.OS === 'android') {
        StatusBar.setBackgroundColor('#0D9DEF', true);
      }
      StatusBar.setBarStyle('light-content');
    }
  }, []);

  useEffect(() => {
    onHeaderRefresh();
  }, [status]);

  useEffect(() => {
    if (village_id || group_id || building_id || room_id) {
      onHeaderRefresh();
    }
  }, [village_id, group_id, building_id, room_id]);

  // 下拉刷新
  const onHeaderRefresh = async () => {
    setPage(1);
    setData([]);

    setRefreshState(RefreshState.HeaderRefreshing);

    let result = {};
    if (params.type === 'smoke') {
      result = await iot.getSmokes({ page: 1, status, village_id, group_id, building_id, room_id });
    } else {
      result = await iot.getLocks({ page: 1, status, village_id, group_id, building_id, room_id });
    }
    setPage(2);
    setData(result.data || []);
    setRefreshState(RefreshState.Idle);
  }

  // 上拉加载
  const onFooterRefresh = async () => {
    if (refreshState === RefreshState.NoMoreData) { return }

    setRefreshState(RefreshState.FooterRefreshing);

    let result = {};
    if (params.type === 'smoke') {
      result = await iot.getSmokes({ page, status, village_id, group_id, building_id, room_id });
    } else {
      result = await iot.getLocks({ page, status, village_id, group_id, building_id, room_id });
    }
    setPage(page + 1);
    setData(GLOBAL._.concat(data, result.data || []));
    if ((result.data || []).length === 0) {
      setRefreshState(RefreshState.NoMoreData);
    } else {
      setRefreshState(RefreshState.Idle);
    }
  }

  const renderCell = ({ item, index }) => {
    return (
      <IotCell key={index} info={item} />
    )
  }

  const onChangeTab = (tab, index) => {
    setStatus(index === 0 ? 1 : 0);
  }

  return (
    <SafeAreaView style={styles.container}>
      <Tabs
        tabs={tabs}
        initialPage={0}
        style={styles.container}
        tabBarUnderlineStyle={{ backgroundColor: '#0D9DEF' }}
        tabBarTextStyle={{fontSize: pxToDp(30)}}
        tabBarActiveTextColor='#0D9DEF'
        tabBarInactiveTextColor='#666'
        tabBarUnderlineStyle={{width: screen_width * 0.184, marginLeft: (screen_width - screen_width * 0.184 * 2) / 4 }}
        onChange={onChangeTab}
      >
        {
          tabs.map((tab, index) => (
            <View key={index} tabLabel={tab.label} style={{ flex: 1 }}>
              <View style={styles.drop}>
                <Dropdown selectVillage={(value) => {
                  setVillageId(value.id);
                  setGroupId('');
                  setBuildingId('');
                  setRoomId('');
                }} selectGroup={(value) => {
                  setGroupId(value.id);
                  setBuildingId('');
                  setRoomId('');
                }} selectBuilding={(value) => {
                  setBuildingId(value.id);
                  setRoomId('');
                }} selectRoom={(value) => {
                  setRoomId(value.id);
                }} />
              </View>
              <RefreshListView
                listRef={`RefreshView`}
                style={{ flex: 1 }}
                data={data}
                keyExtractor={(item, idx) => idx.toString()}
                renderItem={renderCell}
                refreshState={refreshState}
                onHeaderRefresh={onHeaderRefresh}
                onFooterRefresh={onFooterRefresh}

                // 可选
                footerRefreshingText='玩命加载中 >.<'
                footerFailureText='我擦嘞，居然失败了 — —！'
                footerNoMoreDataText='没有数据了 — —！'
              />
            </View>
          ))
        }
      </Tabs>
    </SafeAreaView>
  )
}

export default Index;