import React, { useEffect, useState } from 'react';
import { SafeAreaView, View, Text, Image, StatusBar, StyleSheet, Platform } from 'react-native';
import { Button } from 'react-native-elements';

import c_styles from '../../styles';
import pxToDp from '../../core/pxToDp';
import AuthInput from './components/input';
import { auth } from '../../api';

const styles = StyleSheet.create({
  ...c_styles,
  logo_view: { height: pxToDp(480) },
  logo_view_bg: { width: '100%', height: '100%' },
  content: { position: 'absolute', top: 0, left: 0, width: '100%', height: '100%' },
  title: { color: '#fff', fontSize: pxToDp(40), fontWeight: '500', marginTop: pxToDp(136) },
  logo: { width: pxToDp(180), height: pxToDp(180), marginTop: pxToDp(40) },
  input_view: { backgroundColor: '#fff', borderTopRightRadius: pxToDp(30), borderTopLeftRadius: pxToDp(30), marginTop: pxToDp(53), flex: 1, width: '100%' },
  forget_view: { width: pxToDp(551), marginBottom: pxToDp(80) }
})

const Index = (props) => {
  const { navigation } = props;
  const [password, setPassword] = useState('');
  const [password_confirmation, setPasswordConfirmation] = useState('');

  useEffect(() => {
    if (Platform.OS === 'android') {
      StatusBar.setBackgroundColor('#fff');
    }
    StatusBar.setBarStyle('dark-content');

    return () => {
      if (Platform.OS === 'android') {
        StatusBar.setBackgroundColor('#0D9DEF');
      }
      StatusBar.setBarStyle('light-content');
    }
  }, []);

  // 提交
  const submit = async () => {
    if (!password) {
      GLOBAL.Toast.show('请输入您的新密码', 'info', 1);
      return
    }
    if (!password_confirmation) {
      GLOBAL.Toast.show('请再次输入您的新密码', 'info', 1);
      return
    }
    if (password !== password_confirmation) {
      GLOBAL.Toast.show('两次输入的密码不一致', 'info', 1);
      return
    }

    let key = GLOBAL.Toast.show('修改中');
    try {
      let result = await auth.modifyPsd(password, password_confirmation);
      GLOBAL.Toast.hide(key);
      console.log(result);
      GLOBAL.Toast.show('修改成功', 'success', 1, () => {
        navigation.reset({
          index: 0,
          routes: [{ name: 'Login' }],
        });
      });
    } catch(e) {
      console.log(e)
      GLOBAL.Toast.hide(key);
      GLOBAL.Toast.show(e.message || '修改失败', 'fail', 1);
    }
  }

  return (
    <SafeAreaView style={[styles.safeAreaView, styles.flex, styles.align_center]}>
      <AuthInput
        leftIcon={require('../../../assets/images/password.png')}
        styles={{ marginBottom: pxToDp(50), marginTop: pxToDp(50) }}
        isPassword={true}
        placeholder="请输入您的新密码"
        onChangeText={(text) => { setPassword(text); }}
      />
      <AuthInput
        leftIcon={require('../../../assets/images/password.png')}
        styles={{ marginBottom: pxToDp(90) }}
        isPassword={true}
        placeholder="请再次输入您的新密码"
        onChangeText={(text) => { setPasswordConfirmation(text); }}
      />
      <Button
        title='确定并返回登录'
        containerStyle={{ width: pxToDp(550) }}
        buttonStyle={{ backgroundColor: '#0D9DEF', height: pxToDp(78), borderRadius: pxToDp(39) }}
        titleStyle={{ fontSize: pxToDp(30) }}
        onPress={submit}
      />
    </SafeAreaView>
  )
}

export default Index;