import React, { useEffect, useState } from 'react';
import { useSelector, useDispatch } from 'react-redux';
import { SafeAreaView, View, StatusBar, StyleSheet, Image, Text, Platform } from 'react-native';
import { Flex } from '@ant-design/react-native';
import { SearchBar } from 'react-native-elements';

import c_styles from '../../styles';
import pxToDp from '../../core/pxToDp';
import { RefreshState, RefreshListView } from '../../components';
import TotalCell from './components/totalcell';
import Dropdown from '../tenant/components/dropdown';
import { record } from '../../api';

const styles = StyleSheet.create({
  ...c_styles,
  date: { marginLeft: pxToDp(30), marginRight: pxToDp(30), marginTop: pxToDp(20) },
  drop: { height: pxToDp(80), backgroundColor: '#fff', paddingLeft: pxToDp(30), paddingRight: pxToDp(30) },
  tabs: { marginLeft: pxToDp(30), marginRight: pxToDp(30), paddingTop: pxToDp(30), paddingBottom: pxToDp(20) },
  tab_text: { fontSize: pxToDp(30), color: '#666' },
  tab_text_sel: { color: '#0D9DEF', fontWeight: '500' },
  tab_underline: { height: pxToDp(2), marginTop: pxToDp(10) },
  tab_underline_sel: { backgroundColor: '#0D9DEF' },
});

const Index = (props) => {
  const { navigation, route } = props;
  const params = route.params || {};
  const start_date = params.start_date;
  const end_date = params.end_date;
  const [page, setPage] = useState(1);
  const [refreshState, setRefreshState] = useState(RefreshState.Idle);
  const [open_total, setOpenTotal] = useState(0);
  const [warning_total, setWarningTotal] = useState(0);
  const [data, setData] = useState([]);
  const [tabIndex, setTabIndex] = useState(0);
  const [q, setQ] = useState('');
  const [village_id, setVillageId] = useState('');
  const [group_id, setGroupId] = useState('');
  const [building_id, setBuildingId] = useState('');
  const [room_id, setRoomId] = useState('');

  useEffect(() => {
    if (Platform.OS === 'android') {
      StatusBar.setBackgroundColor('#fff');
    }
    StatusBar.setBarStyle('dark-content');
    navigation.setOptions({ title: params.title || '' });
    getTotal();
    // onHeaderRefresh();

    return () => {
      if (Platform.OS === 'android') {
        StatusBar.setBackgroundColor('#0D9DEF', true);
      }
      StatusBar.setBarStyle('light-content');
    }
  }, []);

  useEffect(() => {
    onHeaderRefresh();
  }, [tabIndex, q]);

  useEffect(() => {
    if (village_id || group_id || building_id || room_id) {
      onHeaderRefresh();
    }
  }, [village_id, group_id, building_id, room_id]);

  // 切换记录
  const switchTab = (index) => {
    setTabIndex(index);
  }

  // 下拉刷新
  const onHeaderRefresh = async () => {
    setPage(1);
    setData([]);

    setRefreshState(RefreshState.HeaderRefreshing);

    let result = {};
    if (tabIndex === 0) {
      result = await record.getOpenRecords({ page: 1, start_date, end_date, q, village_id, group_id, building_id, room_id });
      setOpenTotal(result.total);
    } else {
      result = await record.getWarningRecords({ page: 1, start_date, end_date, q, village_id, group_id, building_id, room_id });
      setWarningTotal(result.total);
    }

    setPage(2);
    setData(result.data || []);
    setRefreshState(RefreshState.Idle);
  }

  // 上拉加载
  const onFooterRefresh = async () => {
    if (refreshState === RefreshState.NoMoreData) { return }

    setRefreshState(RefreshState.FooterRefreshing);

    let result = {};
    if (tabIndex === 0) {
      result = await record.getOpenRecords({ page, start_date, end_date, q, village_id, group_id, building_id, room_id });
    } else {
      result = await record.getWarningRecords({ page, start_date, end_date, q, village_id, group_id, building_id, room_id });
    }

    setPage(page + 1);
    setData(GLOBAL._.concat(data, result.data || []));
    if ((result.data || []).length === 0) {
      setRefreshState(RefreshState.NoMoreData);
    } else {
      setRefreshState(RefreshState.Idle);
    }
  }

  // 获取记录总数
  const getTotal = async () => {
    let open_result = await record.getOpenRecords({page: 1, start_date, end_date});
    let warning_result = await record.getWarningRecords({page: 1, start_date, end_date});
    setOpenTotal(open_result.total);
    setWarningTotal(warning_result.total);
  }

  const renderCell = ({ item, index }) => {
    return (
      <TotalCell key={index} info={item} type={tabIndex === 0 ? 'lock' : 'smoke'} />
    )
  }

  return (
    <SafeAreaView style={styles.container}>
      <SearchBar
        value={q}
        returnKeyType='search'
        containerStyle={{ backgroundColor: '#fff', borderTopWidth: 0, borderBottomWidth: 0, height: pxToDp(100), padding: pxToDp(30), paddingTop: pxToDp(20) }}
        inputContainerStyle={{ backgroundColor: '#f5f5f5', height: pxToDp(60), borderRadius: pxToDp(30) }}
        inputStyle={{ fontSize: pxToDp(26), marginLeft: pxToDp(10) }}
        searchIcon={<Image style={{ width: pxToDp(24), height: pxToDp(26) }} source={require('../../../assets/images/sousuo.png')} />}
        leftIconContainerStyle={{ marginLeft: pxToDp(30) }}
        onChangeText={(text) => {
          setQ(text);
        }}
        placeholder='请输入姓名/手机号码进行搜索'
        placeholderTextColor="#999"
      />
      <View style={styles.drop}>
        <Dropdown selectVillage={(value) => {
          setVillageId(value.id);
          setGroupId('');
          setBuildingId('');
          setRoomId('');
        }} selectGroup={(value) => {
          setGroupId(value.id);
          setBuildingId('');
          setRoomId('');
        }} selectBuilding={(value) => {
          setBuildingId(value.id);
          setRoomId('');
        }} selectRoom={(value) => {
          setRoomId(value.id);
        }} />
      </View>
      <Flex style={styles.tabs}>
        <Flex.Item>
          <Flex direction='column'>
            <Touchable noHighlight onPress={() => { switchTab(0); }}>
              <Text style={[styles.tab_text, tabIndex === 0 ? styles.tab_text_sel : {}]}>开门记录({open_total})</Text>
              <View style={[styles.tab_underline, tabIndex === 0 ? styles.tab_underline_sel : {}]}></View>
            </Touchable>
          </Flex>
        </Flex.Item>
        <Flex.Item>
          <Flex direction='column'>
            <Touchable noHighlight onPress={() => { switchTab(1); }}>
              <Text style={[styles.tab_text, tabIndex === 1 ? styles.tab_text_sel : {}]}>报警记录({warning_total})</Text>
              <View style={[styles.tab_underline, tabIndex === 1 ? styles.tab_underline_sel : {}]}></View>
            </Touchable>
          </Flex>
        </Flex.Item>
      </Flex>
      <RefreshListView
        listRef={`RefreshView`}
        style={{ flex: 1 }}
        data={data}
        keyExtractor={(item, idx) => idx.toString()}
        renderItem={renderCell}
        refreshState={refreshState}
        onHeaderRefresh={onHeaderRefresh}
        onFooterRefresh={onFooterRefresh}

        // 可选
        footerRefreshingText='玩命加载中 >.<'
        footerFailureText='我擦嘞，居然失败了 — —！'
        footerNoMoreDataText='没有数据了 — —！'
      />
    </SafeAreaView>
  )
}

export default Index;