import React, { useState, useEffect } from 'react';
import { StatusBar, StyleSheet, View, Platform } from 'react-native';
import { Button, Text } from 'react-native-elements';
import { AlbumView } from 'teaset';
import FeatherIcon from 'react-native-vector-icons/Feather';

import commonStyles from '../../styles';

const styles = StyleSheet.create({
  ...commonStyles,
  contentStyle: { position: 'absolute', bottom: 0, left: 0, width: '100%', padding: 15, paddingTop: 10, paddingBottom: 30, backgroundColor: 'rgba(0,0,0,0.7)' },
  contentTextStyle: { fontSize: 14, color: '#fff' },
});

const Preview = (props) => {
  const { navigation, route } = props;
  const params = route.params || {};
  const { images = [], defaultIndex = 0 } = params;
  const [preImages, setPreImages] = useState([]);
  const [curIndex, setCurIndex] = useState(0);

  useEffect(() => {
    if (Platform.OS === 'android') {
      StatusBar.setBackgroundColor('#000');
    }
    StatusBar.setBarStyle('light-content');
    setCurIndex(defaultIndex);
    setPreImages(GLOBAL._.map(images, (item) => {
      return {
        uri: item
      }
    }));

    return function cleanup() {
      if (Platform.OS === 'android') {
        StatusBar.setBackgroundColor('#fff', true);
      }
      StatusBar.setBarStyle('dark-content');
    }
  }, []);

  useEffect(() => {
    navigation.setOptions({
      headerStyle: { backgroundColor: '#000', shadowOffset: { height: 0 } },
      headerTintColor: '#fff',
      headerTitleStyle: { fontSize: 16, alignSelf: 'center' },
      color: '#fff',
      headerLeft: () => (
        <Button
          buttonStyle={{padding: 0}}
          type="clear"
          icon={<FeatherIcon name="chevron-left" size={32} color="#fff" />}
          onPress={() => { navigation.goBack(); }}
        />
      ),
      headerRight: () => (
        <Button buttonStyle={{padding: 0}} type="clear"/>
      )
    });
  }, [curIndex]);

  return (
    <View style={[styles.safeAreaView, { backgroundColor: "#000", position: 'relative' }]}>
      <AlbumView
        style={{ flex: 1 }}
        maxScale={5}
        defaultIndex={defaultIndex}
        images={preImages}
        onChange={(index) => {
          setCurIndex(index);
        }}
      />
    </View>
  )
}

export default Preview;