import React, { useEffect, useState } from 'react';
import { StyleSheet, Text, View, Image } from 'react-native';
import { Flex } from '@ant-design/react-native';
import ModalDropdown from 'react-native-modal-dropdown';

import c_styles from '../../../styles';
import pxToDp from '../../../core/pxToDp';
import { area } from '../../../api';

const styles = StyleSheet.create({
  ...c_styles,
  drop_text: { fontSize: pxToDp(24) },
  drop_icon: { width: pxToDp(18), height: pxToDp(11), marginLeft: pxToDp(9) },
  list_item: { padding: pxToDp(20), display: 'flex', flexDirection: 'row', alignItems: 'center' },
  list_item_text: { fontSize: pxToDp(24), width: pxToDp(150) },
  list_item_icon: {width: pxToDp(9), height: pxToDp(14), marginLeft: pxToDp(15)}
});

const Index = (props) => {
  let info = props.info || {};
  const [village_data, setVillageData] = useState([]);
  const [group_data, setGroupData] = useState([]);
  const [building_data, setBuildingData] = useState([]);
  const [room_data, setRoomData] = useState([]);
  const [sel_village, setSelVillage] = useState({});
  const [sel_group, setSelGroup] = useState({});
  const [sel_building, setSelBuilding] = useState({});
  const [sel_room, setSelRoom] = useState({});

  useEffect(() => {
    getVillages();
  }, []);

  useEffect(() => {
    if (!GLOBAL._.isEmpty(sel_village)) {
      getGroups(sel_village.id);
    }
  }, [sel_village]);

  useEffect(() => {
    if (!GLOBAL._.isEmpty(sel_group)) {
      getBuildings(sel_group.id);
    }
  }, [sel_group]);

  useEffect(() => {
    if (!GLOBAL._.isEmpty(sel_building)) {
      getRooms(sel_building.id);
    }
  }, [sel_building]);

  const getVillages = async () => {
    let result = await area.getVillages();
    setVillageData(result);
  }

  const getGroups = async (v_id) => {
    let result = await area.getGroups(v_id);
    setGroupData(result);
  }

  const getBuildings = async (g_id) => {
    let result = await area.getBuildings(g_id);
    setBuildingData(result);
  }

  const getRooms = async (b_id) => {
    let result = await area.getRooms(b_id);
    setRoomData(result);
  }

  return (
    <View style={[props.style || {}]}>
      <Flex justify='around' style={{ height: '100%' }}>
        <ModalDropdown dropdownStyle={{height: pxToDp(400), marginTop: pxToDp(10), backgroundColor: '#fff'}} options={village_data} renderRow={(option, index, isSelected) => {
          return (
            <View key={option.id} style={styles.list_item}>
              <Text style={[styles.list_item_text, sel_village.id === option.id ? styles.theme_color : styles.theme_text]}>{option.title || ''}</Text>
              <Image style={styles.list_item_icon} source={require('../../../../assets/images/right.png')} />
            </View>
          )
        }} onSelect={(index, value) => {
          props.selectVillage && props.selectVillage(value);
          setSelVillage(value);
          setSelGroup({});
          setSelBuilding({});
          setSelRoom({});
        }}>
          <Flex>
            <Text style={[styles.drop_text, styles.theme_text]}>{sel_village.title || '所在村/社区'}</Text>
            <Image style={styles.drop_icon} source={require('../../../../assets/images/xiala.png')} />
          </Flex>
        </ModalDropdown>
        <ModalDropdown dropdownStyle={{marginTop: pxToDp(10)}} options={group_data} renderRow={(option, index, isSelected) => {
          return (
            <View key={option.id} style={styles.list_item}>
              <Text style={[styles.list_item_text, sel_group.id === option.id ? styles.theme_color : styles.theme_text]}>{option.title || ''}</Text>
              <Image style={styles.list_item_icon} source={require('../../../../assets/images/right.png')} />
            </View>
          )
        }} onSelect={(index, value) => {
          props.selectGroup && props.selectGroup(value);
          setSelGroup(value);
          setSelBuilding({});
          setSelRoom({});
        }}>
          <Flex>
            <Text style={[styles.drop_text, styles.theme_text]}>{sel_group.title || '所在小组/小区'}</Text>
            <Image style={styles.drop_icon} source={require('../../../../assets/images/xiala.png')} />
          </Flex>
        </ModalDropdown>
        <ModalDropdown dropdownStyle={{marginTop: pxToDp(10)}} options={building_data} renderRow={(option, index, isSelected) => {
          return (
            <View key={option.id} style={styles.list_item}>
              <Text style={[styles.list_item_text, sel_building.id === option.id ? styles.theme_color : styles.theme_text]}>{option.title || ''}</Text>
              <Image style={styles.list_item_icon} source={require('../../../../assets/images/right.png')} />
            </View>
          )
        }} onSelect={(index, value) => {
          props.selectBuilding && props.selectBuilding(value);
          setSelBuilding(value);
          setSelRoom({});
        }}>
          <Flex>
            <Text style={[styles.drop_text, styles.theme_text]}>{sel_building.title || '所在楼栋'}</Text>
            <Image style={styles.drop_icon} source={require('../../../../assets/images/xiala.png')} />
          </Flex>
        </ModalDropdown>
        <ModalDropdown dropdownStyle={{marginTop: pxToDp(10)}} options={room_data} renderRow={(option, index, isSelected) => {
          return (
            <View key={option.id} style={styles.list_item}>
              <Text style={[styles.list_item_text, sel_room.id === option.id ? styles.theme_color : styles.theme_text]}>{option.title || ''}</Text>
              <Image style={styles.list_item_icon} source={require('../../../../assets/images/right.png')} />
            </View>
          )
        }} onSelect={(index, value) => {
          props.selectRoom && props.selectRoom(value);
          setSelRoom(value);
        }}>
          <Flex>
            <Text style={[styles.drop_text, styles.theme_text]}>{sel_room.title || '房间号码'}</Text>
            <Image style={styles.drop_icon} source={require('../../../../assets/images/xiala.png')} />
          </Flex>
        </ModalDropdown>
      </Flex>
    </View>
  )
}

export default Index