import React, { useState } from 'react';
import { StyleSheet, Text, View } from 'react-native';
import { Flex } from '@ant-design/react-native';
import { Button } from 'react-native-elements';

import c_styles from '../../../styles';
import pxToDp from '../../../core/pxToDp';
import ImagePickerView from './imagepicker';

const styles = StyleSheet.create({
  ...c_styles,
  container_style: { backgroundColor: '#fff', borderRadius: pxToDp(10), padding: pxToDp(30), marginLeft: pxToDp(30), marginRight: pxToDp(30), marginBottom: pxToDp(20) },
  left_text: { fontSize: pxToDp(28), color: '#666' },
  info_text: { fontSize: pxToDp(28), flex: 1 },
});

const Index = (props) => {
  let info = props.info || {};
  let statusText = info.audited_status_zh || '';
  let statusColor = '';
  if (info.audited_status === 1) {
    statusColor = '#999999';
  } else if (info.audited_status === 2) {
    statusColor = '#00C22E';
  } else if (info.audited_status === 3) {
    statusColor = '#FF3030';
  }

  return (
    <View style={[styles.container_style, props.style || {}]}>
      <Flex justify='between' style={{ marginBottom: pxToDp(30) }}>
        <Text style={[styles.theme_text, { fontSize: pxToDp(28) }]}>{info.name || ''}</Text>
        <Text style={{ fontSize: pxToDp(28), color: statusColor }}>{statusText}</Text>
      </Flex>
      <View style={{ height: pxToDp(1), width: '100%', backgroundColor: '#e1e1e1' }}></View>
      <Flex justify='start' style={{ marginBottom: pxToDp(30), marginTop: pxToDp(30) }}>
        <Text style={[styles.left_text]}>申请时间：</Text>
        <Text style={[styles.info_text, styles.theme_text]}>{GLOBAL.moment(info.created_at || '').format('YYYY-MM-DD')}</Text>
      </Flex>
      <Flex justify='start' style={{ marginBottom: pxToDp(30) }}>
        <Text style={[styles.left_text]}>身份证号：</Text>
        <Text style={[styles.info_text, styles.theme_text]}>{info.ID_number || ''}</Text>
      </Flex>
      <Flex justify='start' style={{ marginBottom: pxToDp(30) }}>
        <Text style={[styles.left_text]}>联系电话：</Text>
        <Text style={[styles.info_text, styles.theme_text]}>{info.mobile || ''}</Text>
      </Flex>
      <Flex justify='start' style={{ marginBottom: pxToDp(30) }}>
        <Text style={[styles.left_text]}>详细地址：</Text>
        <Text style={[styles.info_text, styles.theme_text]}>{info.village_title || ''}{info.group_title || ''}{info.building_title || ''}{info.room_title || ''}</Text>
      </Flex>
      <Flex align='start'>
        <Text style={[styles.left_text]}>其他凭证：</Text>
        <ImagePickerView
          showAdd={false}
          images={info.voucher || []}
          onImageClick={(idx, images) => {
            props.onImageClick && props.onImageClick(idx, images);
          }}
        />
      </Flex>
      <Flex justify='end'>
        <Button
          title='拒绝'
          containerStyle={{ marginRight: pxToDp(20) }}
          buttonStyle={{ backgroundColor: '#FF3030', paddingTop: 0, paddingBottom: 0, paddingLeft: pxToDp(20), paddingRight: pxToDp(20), height: pxToDp(48), borderRadius: pxToDp(48) }}
          titleStyle={{ fontSize: pxToDp(24), color: '#fff' }}
          onPress={() => {
            props.refuse && props.refuse(info);
          }}
        />
        <Button
          title='通过'
          buttonStyle={{ backgroundColor: '#00C22E', paddingTop: 0, paddingBottom: 0, paddingLeft: pxToDp(20), paddingRight: pxToDp(20), height: pxToDp(48), borderRadius: pxToDp(48) }}
          titleStyle={{ fontSize: pxToDp(24), color: '#fff' }}
          onPress={() => {
            props.pass && props.pass(info);
          }}
        />
      </Flex>
    </View>
  )
}

export default Index