import React from 'react';
import { View, StyleSheet, Image, Text } from 'react-native';
import AntDesignIcon from 'react-native-vector-icons/AntDesign';

import pxToDp from '../../../core/pxToDp';
import { Touchable } from '../../../components';

const styles = StyleSheet.create({
    container: {
        display: 'flex',
        flexWrap: 'wrap',
        flexDirection: 'row',
        flex: 1
    },
    size: {
        width: pxToDp(120),
        height: pxToDp(120)
    },
    item: {
        borderRadius: pxToDp(10),
        marginRight: pxToDp(20),
        marginBottom: pxToDp(20),
        // overflow: 'hidden',
    },
    image: {
        borderRadius: pxToDp(10),
        overflow: 'hidden'
    },
    closeWrap: {
        width: 20,
        height: 20,
        position: 'absolute',
        top: -6,
        right: -6,
        justifyContent: 'center',
        alignItems: 'center',
        overflow: 'hidden',
        borderRadius: 3
    },
    closeText: {
        color: '#fff',
        backgroundColor: 'transparent',
        fontSize: 20,
        height: 20,
        marginTop: -8,
        fontWeight: '300'
    }
});

export default ImagePicker = (props) => {
    const {
        showPicker = () => { },
        removeImage = () => { },
        onImageClick = () => { },
        images = [],
        showAdd,
        showRemove
    } = props;

    return (
        <View style={styles.container}>
            {
                (images || []).map((item, index) => (
                    <View key={`${item}_${index}`} style={[styles.item, styles.size]}>
                        <Touchable onPress={() => onImageClick(index, images)} activeOpacity={0.6}>
                            <Image source={{ uri: item }} style={[styles.size, styles.image]} />
                        </Touchable>
                        {
                            showRemove && (
                                <View style={styles.closeWrap}>
                                    <Touchable onPress={() => removeImage(index)}>
                                        <AntDesignIcon name='closecircle' size={17} color='#F4626C' />
                                    </Touchable>
                                </View>
                            )
                        }
                    </View>
                ))
            }
            {
                showAdd && (
                    <Touchable onPress={() => showPicker()}>
                        <Image style={[styles.item, styles.size]} source={require('../../../../assets/images/photo.png')} />
                    </Touchable>
                )
            }
        </View>
    )
}
