import React, { useEffect, useState } from 'react';
import { useSelector, useDispatch } from 'react-redux';
import { SafeAreaView, View, StyleSheet, Image, Text } from 'react-native';
import { Flex } from '@ant-design/react-native';

import c_styles from '../../styles';
import pxToDp from '../../core/pxToDp';
import ImagePickerView from './components/imagepicker';
import { tenant } from '../../api';

const styles = StyleSheet.create({
  ...c_styles,
  info_view: { margin: pxToDp(30), marginTop: pxToDp(20), padding: pxToDp(30), backgroundColor: '#fff', borderRadius: pxToDp(10) },
  left_text: { fontSize: pxToDp(28), color: '#666' },
  info_text: { fontSize: pxToDp(28), flex: 1 },
});

const Index = (props) => {
  const { navigation, route } = props;
  const params = route.params || {};
  const [data, setData] = useState({});

  useEffect(() => {
    getTenantInfo();
  }, []);

  // 获取租客详情信息
  const getTenantInfo = async () => {
    let result = await tenant.info(params.id);
    setData(result);
  }

  return (
    <SafeAreaView style={styles.container}>
      <View style={styles.info_view}>
        <Text style={[styles.theme_text, { fontSize: pxToDp(28), marginBottom: pxToDp(30) }]}>{data.name || ''}</Text>
        <View style={{ height: pxToDp(1), width: '100%', backgroundColor: '#e1e1e1' }}></View>
        <Flex style={{ marginBottom: pxToDp(30), marginTop: pxToDp(30) }}>
          <Text style={[styles.left_text]}>联系电话：</Text>
          <Text style={[styles.info_text, styles.theme_text]}>{data.mobile || ''}</Text>
        </Flex>
        <Flex style={{ marginBottom: pxToDp(30) }}>
          <Text style={[styles.left_text]}>申请时间：</Text>
          <Text style={[styles.info_text, styles.theme_text]}>{GLOBAL.moment(data.created_at || '').format('YYYY-MM-DD')}</Text>
        </Flex>
        <Flex style={{ marginBottom: pxToDp(30) }}>
          <Text style={[styles.left_text]}>详细地址：</Text>
          <Text style={[styles.info_text, styles.theme_text]}>{data.village_title || ''}{data.group_title || ''}{data.building_title || ''}{data.room_title || ''}</Text>
        </Flex>
        <Flex style={{ marginBottom: pxToDp(30) }}>
          <Text style={[styles.left_text]}>身份证号：</Text>
          <Text style={[styles.info_text, styles.theme_text]}>{data.ID_number || ''}</Text>
        </Flex>
        <Flex style={{ marginBottom: pxToDp(30) }}>
          <Text style={[styles.left_text]}>租客性别：</Text>
          <Text style={[styles.info_text, styles.theme_text]}>{data.gender_zh || ''}</Text>
        </Flex>
        <Flex style={{ marginBottom: pxToDp(30) }}>
          <Text style={[styles.left_text]}>出生年月：</Text>
          <Text style={[styles.info_text, styles.theme_text]}>{data.birthday || '-'}</Text>
        </Flex>
        <Flex align='start'>
          <Text style={[styles.left_text]}>其他凭证：</Text>
          <ImagePickerView
            showAdd={false}
            images={data.voucher || []}
            onImageClick={(idx, images) => {
              navigation.navigate('Preview', {
                images: images,
                defaultIndex: idx
              });
            }}
          />
        </Flex>
      </View>
    </SafeAreaView>
  )
}

export default Index;