import React, { useEffect, useState } from 'react';
import { useSelector, useDispatch } from 'react-redux';
import { SafeAreaView, View, StatusBar, StyleSheet, Image, Text, Platform } from 'react-native';
import { Flex } from '@ant-design/react-native';
import { SearchBar } from 'react-native-elements';

import c_styles from '../../styles';
import pxToDp from '../../core/pxToDp';
import { RefreshState, RefreshListView } from '../../components';
import ListCell from './components/listcell';
import Dropdown from './components/dropdown';
import { tenant } from '../../api';

const styles = StyleSheet.create({
  ...c_styles,
  drop: { height: pxToDp(80), marginLeft: pxToDp(30), marginRight: pxToDp(30) },
});

const Index = (props) => {
  const { navigation } = props;
  const [page, setPage] = useState(1);
  const [refreshState, setRefreshState] = useState(RefreshState.Idle);
  const [data, setData] = useState([]);
  const [q, setQ] = useState('');
  const [village_id, setVillageId] = useState('');
  const [group_id, setGroupId] = useState('');
  const [building_id, setBuildingId] = useState('');
  const [room_id, setRoomId] = useState('');

  useEffect(() => {
    if (Platform.OS === 'android') {
      StatusBar.setBackgroundColor('#fff');
    }
    StatusBar.setBarStyle('dark-content');
    // onHeaderRefresh();

    return () => {
      if (Platform.OS === 'android') {
        StatusBar.setBackgroundColor('#0D9DEF', true);
      }
      StatusBar.setBarStyle('light-content');
    }
  }, []);

  useEffect(() => {
    onHeaderRefresh();
  }, [q]);

  useEffect(() => {
    if (village_id || group_id || building_id || room_id) {
      onHeaderRefresh();
    }
  }, [village_id, group_id, building_id, room_id]);

  // 下拉刷新
  const onHeaderRefresh = async () => {
    setPage(1);
    setData([]);

    setRefreshState(RefreshState.HeaderRefreshing);

    let result = await tenant.list({ page: 1, q, village_id, group_id, building_id, room_id });
    setPage(2);
    setData(result.data || []);
    setRefreshState(RefreshState.Idle);
  }

  // 上拉加载
  const onFooterRefresh = async () => {
    if (refreshState === RefreshState.NoMoreData) { return }

    setRefreshState(RefreshState.FooterRefreshing);

    let result = await tenant.list({ page, q, village_id, group_id, building_id, room_id });
    setPage(page + 1);
    setData(GLOBAL._.concat(data, result.data || []));
    if ((result.data || []).length === 0) {
      setRefreshState(RefreshState.NoMoreData);
    } else {
      setRefreshState(RefreshState.Idle);
    }
  }

  const renderCell = ({ item, index }) => {
    return (
      <ListCell key={index} info={item} clickCell={(info) => {
        navigation.navigate('TenantDetail', {
          id: info.id
        });
      }} />
    )
  }

  return (
    <SafeAreaView style={styles.container}>
      <SearchBar
        value={q}
        returnKeyType='search'
        containerStyle={{ backgroundColor: '#fff', borderTopWidth: 0, borderBottomWidth: 0, height: pxToDp(100), padding: pxToDp(30), paddingTop: pxToDp(20) }}
        inputContainerStyle={{ backgroundColor: '#f5f5f5', height: pxToDp(60), borderRadius: pxToDp(30) }}
        inputStyle={{ fontSize: pxToDp(26), marginLeft: pxToDp(10) }}
        searchIcon={<Image style={{ width: pxToDp(24), height: pxToDp(26) }} source={require('../../../assets/images/sousuo.png')} />}
        leftIconContainerStyle={{ marginLeft: pxToDp(30) }}
        onChangeText={(text) => {
          setQ(text);
        }}
        placeholder='请输入姓名/手机号码进行搜索'
        placeholderTextColor="#999"
      />
      <View style={styles.drop}>
        <Dropdown selectVillage={(value) => {
          setVillageId(value.id);
          setGroupId('');
          setBuildingId('');
          setRoomId('');
        }} selectGroup={(value) => {
          setGroupId(value.id);
          setBuildingId('');
          setRoomId('');
        }} selectBuilding={(value) => {
          setBuildingId(value.id);
          setRoomId('');
        }} selectRoom={(value) => {
          setRoomId(value.id);
        }} />
      </View>
      <RefreshListView
        listRef={`RefreshView`}
        style={{ flex: 1 }}
        data={data}
        keyExtractor={(item, idx) => idx.toString()}
        renderItem={renderCell}
        refreshState={refreshState}
        onHeaderRefresh={onHeaderRefresh}
        onFooterRefresh={onFooterRefresh}

        // 可选
        footerRefreshingText='玩命加载中 >.<'
        footerFailureText='我擦嘞，居然失败了 — —！'
        footerNoMoreDataText='没有数据了 — —！'
      />
    </SafeAreaView>
  )
}

export default Index;